@@ -5,8 +5,7 @@ use warnings;
 
 use Alien::Base::PkgConfig;
 
-our $VERSION = '0.030';
-$VERSION = eval $VERSION;
+our $VERSION = '0.031';
 
 use Carp;
 use DynaLoader ();
@@ -233,6 +232,22 @@ sub libs {
   return $self->_keyword('Libs', @_);
 }
 
+=head2 version
+
+ my $version = Alien::MyLibrary->version;
+
+Returns the version of the Alienized library or tool that was
+determined at install time.
+
+=cut
+
+sub version {
+  my $self = shift;
+  my $version = $self->config('version');
+  chomp $version;
+  return $version;
+}
+
 =head2 install_type
 
  my $install_type = Alien::MyLibrary->install_type;
@@ -441,9 +456,7 @@ sub split_flags_windows {
  my($dll) = Alien::MyLibrary->dynamic_libs;
 
 Returns a list of the dynamic library or shared object files for the
-alien software.  Currently this only works for when C<install_type> is
-C<share> and C<alien_isolate_dynamic> is used (See
-L<Alien::Base::ModuleBuild::API#CONSTRUCTOR> for all build arguments).
+alien software.
 
 =cut
 
@@ -498,6 +511,12 @@ a directory under C<dist_dir> named C<bin> if it exists.  You may wish
 to override the default behavior if you have executables or scripts that
 get installed into non-standard locations.
 
+Example usage:
+
+ use Env qw( @PATH );
+ 
+ unshft @PATH, Alien::MyLibrary->bin_dir;
+
 =cut
 
 sub bin_dir {
@@ -731,7 +750,7 @@ For graciously teaching me about rpath and dynamic loading,
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012-2015 by Joel Berger
+Copyright (C) 2012-2017 by Joel Berger
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
