@@ -3,8 +3,7 @@ package Alien::Base::ModuleBuild;
 use strict;
 use warnings;
 
-our $VERSION = '0.030';
-$VERSION = eval $VERSION;
+our $VERSION = '0.031';
 
 use parent 'Module::Build';
 
@@ -388,6 +387,11 @@ sub ACTION_alien_code {
     local $CWD = $self->alien_temp_dir;
 
     my $file = $cabinet->files->[0];
+    
+    unless (defined $file) {
+      die "no files found in repository";
+    }
+    
     $version = $file->version;
     $self->config_data( alien_version => $version ); # Temporary setting, may be overridden later
 
@@ -737,7 +741,7 @@ sub alien_do_system {
     }
     
     # remove anything already in PATH
-    delete $path{$_} for @PATH;
+    delete $path{$_} for grep { defined $_ } @PATH;
     # add anything else to start of PATH
     unshift @PATH, sort keys %path;
 
@@ -1253,6 +1257,8 @@ build step of your distribution.  When properly configured it will
 
 =head2 alien_check_installed_version
 
+[version 0.001]
+
  my $version = $abmb->alien_check_installed_version;
 
 This function determines if the library is already installed as part of
@@ -1265,11 +1271,23 @@ building does not use C<pkg-config>.
 
 =head2 alien_check_built_version
 
+[version 0.006]
+
  my $version = $amb->alien_check_built_version;
 
 This function determines the version of the library after it has been
 built from source.  This function only gets called if the operating
 system version can not be found and the package is successfully built.
+The version is returned on success.  If the version can't be detected
+then it should return empty list.  Note that failing to detect a version
+is considered a failure and the corresponding C<./Build> action will
+fail!
+
+Any string is valid as a version as far as L<Alien::Base> is concerned.
+The most useful value would be a number or dotted decimal that most
+software developers recognize and that software tools can differentiate.
+In some cases packages will not have a clear version number, in which
+case the string C<unknown> would be a reasonable choice.
 
 The default implementation relies on C<pkg-config>, and other heuristics,
 but you will probably want to override this with your own implementation
@@ -1287,6 +1305,8 @@ provide an implementation for this method.
 
 =head2 alien_extract_archive
 
+[version 0.024]
+
   my $dir = $amb->alien_extract_archive($filename);
 
 This function unpacks the given archive and returns the directory
@@ -1299,6 +1319,8 @@ this method.
 
 =head2 alien_do_system
 
+[version 0.024]
+
   my %result = $amb->alien_do_system($cmd)
 
 Similar to L<Module::Build::do_system>, also sets the path and several
@@ -1379,7 +1401,7 @@ Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt> and the L<Alien::Ba
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012-2015 by Joel Berger
+Copyright (C) 2012-2017 by Joel Berger
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
